Crate servo_capi

Crate servo_capi 

Structs

ServoBuilder
An opaque struct representing builder for a Servo instance. Refer to the documentation of the corresponding [servo::ServoBuilder] struct in Rust API for more information. [servo::ServoBuilder]: https://doc.servo.org/servo/struct.ServoBuilder.html
ServoEventLoopWaker
A callback used by Servo to wake the embedder thread when Servo has new work to process. The embedder is expected to pump Servo’s event loop in response to this callback.

Functions

default_event_loop_waker_wake_callback
A no-op default wake_callback used when the embedder has not set one explicitly.
servo_builder_build
Consumes the builder and creates a new Servo instance.
servo_builder_create
Creates a new ServoBuilder populated with default values.
servo_builder_free
Destroys builder and frees its memory.
servo_builder_set_event_loop_waker
Sets the callback used to wake the embedder’s event loop when Servo has new work to process (e.g, rendering updates).
servo_builder_set_options
Sets the options to be used by the Servo instance.
servo_builder_set_preferences
Sets the preferences to be used by the Servo instance.