#[repr(C)]pub struct ServoEventLoopWaker {
pub wake_callback: extern "C" fn(),
}Expand description
A callback used by Servo to wake the embedder thread when Servo has new work to process. The embedder is expected to pump Servo’s event loop in response to this callback.
Safety
The embedder must ensure that:
wake_callbackis a valid C ABI function matching the signature shown.wake_callbackremains valid for the lifetime of theServoinstance the waker is associated with.wake_callbackdoes not unwind across the FFI boundary.wake_callbackis safe to invoke from any thread, since Servo may call it from internal threads.
Fields
wake_callback: extern "C" fn()Trait Implementations
Sourceimpl Clone for ServoEventLoopWaker
impl Clone for ServoEventLoopWaker
Sourcefn clone(&self) -> ServoEventLoopWaker
fn clone(&self) -> ServoEventLoopWaker
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for ServoEventLoopWaker
Sourceimpl Default for ServoEventLoopWaker
impl Default for ServoEventLoopWaker
Sourceimpl EventLoopWaker for ServoEventLoopWaker
impl EventLoopWaker for ServoEventLoopWaker