An opaque struct representing builder for a Servo instance.
Refer to the documentation of the corresponding
[servo::ServoBuilder] struct in Rust API for more information.
[servo::ServoBuilder]: https://doc.servo.org/servo/struct.ServoBuilder.html
A callback used by Servo to wake the embedder thread when
Servo has new work to process. The embedder is expected to
pump Servo’s event loop in response to this callback.